@@ -491,11 +491,15 @@ parse_uri_substring (const gchar *substring, GnomeVFSURI *parent)
 
 /**
  * gnome_vfs_uri_new:
- * @text_uri: a string representing a uri.
+ * @text_uri: an escaped string representing a uri.
  * 
  * Create a new uri from @text_uri. Unsupported and unsafe methods
  * are not allowed and will result in %NULL being returned. URL
  * transforms are allowed.
+ *
+ * The @a text_uri must be an escaped URI string such as returned by 
+ * gnome_vfs_get_uri_from_local_path(), gnome_vfs_make_uri_from_input(), 
+ * or gtk_file_chooser_get_uri().
  * 
  * Return value: The new uri.
  */
@@ -1117,11 +1121,12 @@ gnome_vfs_uri_append_path (const GnomeVFSURI *uri,
 /**
  * gnome_vfs_uri_append_file_name:
  * @uri: a #GnomeVFSURI.
- * @filename: any "regular" file name (can include #, /, etc).
+ * @filename: any "regular" file name (can include #, /, etc) in the file system encoding. This is not an escaped URI.
  * 
  * Create a new uri obtained by appending @file_name to @uri.  This will take care
  * of adding an appropriate directory separator between the end of @uri and
- * the start of @file_name if necessary.
+ * the start of @file_name if necessary. @file_name might, for instance, be the 
+ * result of a call to g_dir_read_name().
  * 
  * Return value: The new uri obtained by combining @uri and @path.
  */
@@ -1145,8 +1150,18 @@ gnome_vfs_uri_append_file_name (const GnomeVFSURI *uri,
  * @hide_options: bitmask specifying what uri elements (e.g. password,
  * user name etc.) should not be represented in the returned string.
  * 
- * Translate @uri into a printable string.  The string will not contain the
- * uri elements specified by @hide_options.
+ * Translate @uri into a printable string.  The string will not
+ * contain the uri elements specified by @hide_options.
+ *
+ * A file: URI on Win32 might look like file:///x:/foo/bar.txt. Note
+ * that the part after file:// is not a legal file name, you need to
+ * remove the / in front of the drive letter. This function does that
+ * automatically if @hide_options specifies that the toplevel method,
+ * user name, password, host name and host port should be hidden.
+ *
+ * On the other hand, a file: URI for a UNC path looks like
+ * file:////server/share/foo/bar.txt, and in that case the part after
+ * file:// is the correct file name.
  * 
  * Return value: a malloc'd printable string representing @uri.
  */
@@ -1221,7 +1236,21 @@ gnome_vfs_uri_to_string (const GnomeVFSURI *uri,
 	}
 	
 	if (uri->text != NULL) {
+#ifndef G_OS_WIN32
 		g_string_append (string, uri->text);
+#else
+		if (uri->text[0] == '/' &&
+		    g_ascii_isalpha (uri->text[1]) &&
+		    uri->text[2] == ':' &&
+		    (hide_options & GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD) &&
+		    (hide_options & GNOME_VFS_URI_HIDE_USER_NAME) &&
+		    (hide_options & GNOME_VFS_URI_HIDE_PASSWORD) &&
+		    (hide_options & GNOME_VFS_URI_HIDE_HOST_NAME) &&
+		    (hide_options & GNOME_VFS_URI_HIDE_HOST_PORT))
+			g_string_append (string, uri->text + 1);
+		else
+			g_string_append (string, uri->text);
+#endif
 	}
 
 	if (uri->fragment_id != NULL 
