@@ -83,8 +83,6 @@ void               vfs_module_shutdown  (GnomeVFSMethod *method);
 /* ************************************************************************** */
 /* DEBUGING stuff */
 
-/* #define DEBUG_HTTP_ENABLE 1 */
-#undef DEBUG_HTTP_ENABLE
 #ifdef DEBUG_HTTP_ENABLE
 
 void http_debug_printf(const char *func, const char *fmt, ...) G_GNUC_PRINTF (2,3);
@@ -1577,11 +1575,19 @@ http_acquire_connection (HttpContext *context)
 	HttpProxyInfo proxy;
 	ne_session *session;
 	
+
+	if (context->ssl == TRUE &&
+	    ! ne_has_support (NE_FEATURE_SSL)) {
+		DEBUG_HTTP ("SSL not supported!");
+		return GNOME_VFS_ERROR_NOT_SUPPORTED;
+	}
+	
 	top_uri = gnome_vfs_uri_get_toplevel (context->uri);
 
-	if (top_uri == NULL)
+	if (top_uri == NULL) {
 		return GNOME_VFS_ERROR_INVALID_URI;
-	
+	}
+		
 	session = neon_session_pool_lookup (context->uri);
 	
 	if (session != NULL) {
@@ -1677,20 +1683,27 @@ http_context_set_uri (HttpContext *context, GnomeVFSURI *uri)
 {
 	char *uri_string;
 	
-	if (context->uri)
+	if (context->uri) {
 		gnome_vfs_uri_unref (context->uri);
-	
-	if (context->path != NULL)
+	}
+		
+	if (context->path != NULL) {
 		g_free (context->path);
-	
+	}
+		
 	context->uri = gnome_vfs_uri_dup (uri);
 	context->scheme = resolve_alias (gnome_vfs_uri_get_scheme (uri));
 	
 	if (gnome_vfs_uri_get_host_port (context->uri) == 0) {
-		if (g_str_equal (context->scheme, "https"))
-			gnome_vfs_uri_set_host_port (context->uri, DEFAULT_HTTPS_PORT);
-		else 
-			gnome_vfs_uri_set_host_port (context->uri, DEFAULT_HTTP_PORT);
+		if (g_str_equal (context->scheme, "https")) {
+			gnome_vfs_uri_set_host_port (context->uri,
+						     DEFAULT_HTTPS_PORT);
+			context->ssl = TRUE;
+		} else { 
+			gnome_vfs_uri_set_host_port (context->uri,
+						     DEFAULT_HTTP_PORT);
+			context->ssl = FALSE;
+		}
 	}
 	
 	uri_string = gnome_vfs_uri_to_string (context->uri, GNOME_VFS_URI_HIDE_USER_NAME
@@ -1871,7 +1884,6 @@ http_get_file_info (HttpContext *context, GnomeVFSFileInfo *info)
 
 
 	result = resolve_result (res, req);	
-	ne_request_destroy (req);
 	
 	if (result == GNOME_VFS_OK) {
 		const char *name;	
@@ -1895,7 +1907,9 @@ http_get_file_info (HttpContext *context, GnomeVFSFileInfo *info)
 		}
 		
 	}
-
+	
+	ne_request_destroy (req);
+	
 	return result;
 }
 
@@ -2639,9 +2653,10 @@ do_seek (GnomeVFSMethod	      *method,
 	
 	handle = (HttpFileHandle *) method_handle;
 	
-	if (handle->mode & GNOME_VFS_OPEN_READ && handle->can_range != TRUE)
+	if (handle->mode & GNOME_VFS_OPEN_READ && handle->can_range != TRUE) {
 		return GNOME_VFS_ERROR_NOT_SUPPORTED;
-	
+	}
+		
 	result = GNOME_VFS_OK;
 	
 	switch (whence) {
@@ -2673,12 +2688,17 @@ do_seek (GnomeVFSMethod	      *method,
 	
 	}
 	
-	
-	/* REVIEW: is this error correct ? */
+	/* FIXME: is this error correct ? */
 	if (new_position < 0) {
 		DEBUG_HTTP ("seeking to %lld", new_position);
 		return GNOME_VFS_ERROR_NOT_SUPPORTED;
 	}
+
+	/* if we shall seek to where we already are just
+	 * return OK */
+	if (handle->offset == new_position) {
+		return GNOME_VFS_OK;
+	}
 	
 	handle->offset = new_position;
 	
