@@ -69,7 +69,7 @@
 #include <glib/gi18n-lib.h>
 
 #include "sftp.h"
-#include "pty-open.h"
+#include <libgnomevfs/gnome-vfs-pty.h>
 
 size_t default_req_len = 32768;
 guint max_req = 16;
@@ -485,10 +485,13 @@ buffer_read_file_info (Buffer *buf, GnomeVFSFileInfo *info)
 		info->valid_fields |= GNOME_VFS_FILE_INFO_FIELDS_SIZE;
 		info->size = buffer_read_gint64 (buf);
 	}
+	
 	if (flags & SSH2_FILEXFER_ATTR_UIDGID) {
 		info->uid = buffer_read_gint32 (buf);
 		info->gid = buffer_read_gint32 (buf);
+		info->valid_fields |= GNOME_VFS_FILE_INFO_FIELDS_IDS;	
 	}
+	
 	if (flags & SSH2_FILEXFER_ATTR_PERMISSIONS) {
 		info->valid_fields |= GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS;
 		info->permissions = buffer_read_gint32 (buf);
@@ -521,10 +524,6 @@ buffer_read_file_info (Buffer *buf, GnomeVFSFileInfo *info)
 	info->valid_fields |= GNOME_VFS_FILE_INFO_FIELDS_IO_BLOCK_SIZE;
 	info->io_block_size = default_req_len;
 
-	/* Set the uid and gid fields naively to the current user to trick Nautilus */
-	info->uid = getuid ();
-	info->gid = getgid ();
-
 	DEBUG4 (g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "Read file info from %p", buf));
 }
 
@@ -927,7 +926,8 @@ invoke_full_auth (const GnomeVFSURI *uri,
 		  char **user_out,
 		  char **object_out,
 		  char **authtype_out,
-		  gboolean *save_password_out)
+		  gboolean *save_password_out,
+		  gboolean *abort_auth_out)
 {
 	GnomeVFSModuleCallbackFullAuthenticationIn in_args;
 	GnomeVFSModuleCallbackFullAuthenticationOut out_args;
@@ -970,6 +970,8 @@ invoke_full_auth (const GnomeVFSURI *uri,
 		*password_out = NULL;
 	}
 
+	*abort_auth_out = out_args.abort_auth;
+
 	g_free (in_args.uri);
 	g_free (in_args.username);
 	g_free (in_args.object);
@@ -1146,7 +1148,7 @@ sftp_connect (SftpConnection **connection, const GnomeVFSURI *uri)
 
 	tty_fd = -1;
 #ifdef USE_PTY
-	tty_fd =_gnome_vfs_pty_open(&ssh_pid, NULL,
+	tty_fd = gnome_vfs_pty_open(&ssh_pid, GNOME_VFS_PTY_REAP_CHILD, NULL,
 				    args[0], args+1, NULL,
 				    300, 300, 
 				    &out_fd, &in_fd, &err_fd);
@@ -1208,6 +1210,7 @@ sftp_connect (SftpConnection **connection, const GnomeVFSURI *uri)
 		char *endpos;
 		char *hostname = NULL;
 		char *fingerprint = NULL;
+		gboolean aborted;
 
 		if (client_vendor == SFTP_VENDOR_SSH) {
 			prompt_fd = err_fd;
@@ -1244,6 +1247,7 @@ sftp_connect (SftpConnection **connection, const GnomeVFSURI *uri)
 			buffer[len] = 0;
 			if (g_str_has_suffix (buffer, "password: ") ||
 			    g_str_has_suffix (buffer, "Password: ") ||
+			    g_str_has_suffix (buffer, "Password:")  ||
 			    g_str_has_prefix (buffer, "Enter passphrase for key")) {
 				if (!done_auth && gnome_vfs_uri_get_password (uri) != NULL) {
 					password = g_strdup (gnome_vfs_uri_get_password (uri));
@@ -1255,11 +1259,14 @@ sftp_connect (SftpConnection **connection, const GnomeVFSURI *uri)
 					g_io_channel_write_chars (tty_channel, "\n", 1, &len, NULL);
 					g_io_channel_flush (tty_channel, NULL);
 				} else if (invoke_full_auth (uri, done_auth, buffer, &password, &keyring, 
-							     &user, &object, &authtype, &save_password) && password != NULL) {
+							     &user, &object, &authtype, &save_password, &aborted) && password != NULL) {
 					full_auth = TRUE;
 					g_io_channel_write_chars (tty_channel, password, -1, &len, NULL);
 					g_io_channel_write_chars (tty_channel, "\n", 1, &len, NULL);
 					g_io_channel_flush (tty_channel, NULL);
+				} else if (aborted) {
+					res = GNOME_VFS_ERROR_CANCELLED;
+					goto bail;
 				} else {
 					res = GNOME_VFS_ERROR_ACCESS_DENIED;
 					goto bail;
